@@ -30,7 +30,7 @@ from ..aws.s3 import get_file_data_from_s3
 
 
 
-def read_lines(bucket, key, objEventUserMap = None, userIdKey = "userId"):
+def read_lines(bucket, key, objEventUserMap = None, userIdKey = "userId",  session = boto3.Session()):
     
     try:
 
@@ -43,7 +43,7 @@ def read_lines(bucket, key, objEventUserMap = None, userIdKey = "userId"):
 
 
 
-        raw_data = get_file_data_from_s3(bucket=bucket, key=key) 
+        raw_data = get_file_data_from_s3(bucket=bucket, key=key, session=session) 
 
         i_line = 0
         for line in raw_data.splitlines():
